==> haskell-monad-par-extras-0.3.3-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-2vWsGpC2vWO8bpIKz1PKmI
key:                  monad-par-extras-0.3.3-2vWsGpC2vWO8bpIKz1PKmI
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  c25fd11f38b14db6e474848cec73293e
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-par-extras-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par-extras
hs-libraries:         HSmonad-par-extras-0.3.3-2vWsGpC2vWO8bpIKz1PKmI
depends:
    abstract-par-0.3.3-7WRIVoWpARZGuBib8Nevl1 base-4.17.2.1
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT deepseq-1.4.8.0 mtl-2.2.2
    random-1.2.1.2-5fVld2gnCLrE5XXQdXAodw transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-247-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-6iDPtGCCf7B29FBX5xBIWd
key:                  monad-par-extras-0.3.3-6iDPtGCCf7B29FBX5xBIWd
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  daa677fa13e745e3458934663e4f410d
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-par-extras-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par-extras
hs-libraries:         HSmonad-par-extras-0.3.3-6iDPtGCCf7B29FBX5xBIWd
depends:
    abstract-par-0.3.3-7WRIVoWpARZGuBib8Nevl1 base-4.17.2.1
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT deepseq-1.4.8.0 mtl-2.2.2
    random-1.2.1.2-KXwyGxW8gFCDB692Rea4Jy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
